<?php
/*
Plugin Name: WooCommerce Redirect After Order
Description: Redirect users to a specific page after order completion.
Version: 1.0
Author: EasyToolsWP.com
*/

// Hook to WooCommerce order complete action
add_action('woocommerce_thankyou', 'woo_redirect_after_order');

function woo_redirect_after_order($order_id) {
    if (!is_wc_endpoint_url('order-received')) {
        return;
    }
    $redirect_option = get_option('woo_redirect_option');
    
    switch ($redirect_option) {
        case 'order':
            $redirect_url = wc_get_endpoint_url('orders', '', wc_get_page_permalink('myaccount'));
            break;
        case 'dashboard':
            $redirect_url = wc_get_endpoint_url('dashboard', '', wc_get_page_permalink('myaccount'));
            break;
        case 'downloads':
            $redirect_url = wc_get_endpoint_url('downloads', '', wc_get_page_permalink('myaccount'));
            break;
        default:
            $redirect_url = wc_get_checkout_url();
            break;
    }

    wp_redirect($redirect_url);
    exit;
}

// Add a settings page for the plugin
add_action('admin_menu', 'woo_redirect_after_order_menu');

function woo_redirect_after_order_menu() {
    add_options_page(
        'WooCommerce Redirect After Order',
        'WooCommerce Redirect After Order',
        'manage_options',
        'woo-redirect-after-order',
        'woo_redirect_after_order_settings_page'
    );
}

function woo_redirect_after_order_settings_page() {
    ?>
    <div class="wrap">
        <h1>WooCommerce Redirect After Order Settings</h1>
        <form method="post" action="options.php">
            <?php
            settings_fields('woo_redirect_after_order_options');
            do_settings_sections('woo-redirect-after-order');
            submit_button();
            ?>
        </form>
    </div>
    <?php
}

add_action('admin_init', 'woo_redirect_after_order_settings');

function woo_redirect_after_order_settings() {
    register_setting('woo_redirect_after_order_options', 'woo_redirect_option');
    
    add_settings_section(
        'woo_redirect_after_order_section',
        'Redirect Settings',
        null,
        'woo-redirect-after-order'
    );

    add_settings_field(
        'woo_redirect_option',
        'Redirect After Order Completion',
        'woo_redirect_option_callback',
        'woo-redirect-after-order',
        'woo_redirect_after_order_section'
    );
}

function woo_redirect_option_callback() {
    $options = array(
        'order' => 'Account > Orders',
        'dashboard' => 'Account > Dashboard',
        'downloads' => 'Account > Downloads'
    );

    $selected_option = get_option('woo_redirect_option', 'dashboard');
    echo '<select name="woo_redirect_option">';
    foreach ($options as $value => $label) {
        $selected = ($value === $selected_option) ? 'selected' : '';
        echo "<option value='$value' $selected>$label</option>";
    }
    echo '</select>';
}
?>
